package eu.dnetlib.data.proto;

import "Kind.proto";
import "FieldType.proto";

// for DNGFentity
import "Type.proto";
import "Datasource.proto";
import "Organization.proto";
import "Person.proto";
import "Project.proto";
import "Publication.proto";
import "Dataset.proto";

// for DNGFRel
import "RelType.proto";
import "Rels.proto";

option java_package = "eu.dnetlib.data.proto";
option java_outer_classname = "DNGFProtos";

message DNGF {
  required Kind kind = 1;

  optional DNGFEntity entity = 2;
  optional DNGFRel rel = 3;

  optional DataInfo dataInfo = 4;

  // used to mark the last update time of this object
  optional sfixed64 lastupdatetimestamp = 5;
}

message DNGFEntity {

  extensions 100 to 199;

  required Type type = 1;
  required string id = 12;

  repeated string originalId = 8;
  repeated KeyValue collectedfrom = 9;

  repeated StructuredProperty pid = 10;
  optional string dateofcollection = 11;
  optional string dateoftransformation = 13;

  /* Any relation that we want to bundle together with this entity.
   It's intended to be used only in temporary values in map/red jobs (sequence files, ...)
   and never persisted values stored in  HBase. */
  repeated DNGFRel cachedRel = 2;

  optional Datasource datasource = 3;
  optional Organization organization = 4;
  optional Person person = 5;
  optional Project project = 6;
  optional Publication publication = 7;
  optional Dataset dataset = 14;

  repeated DNGFEntity children = 16;

  repeated ExtraInfo extraInfo = 15;

  optional OAIProvenance oaiprovenance = 17;
}


message DNGFRel {
  required RelType relType = 1;
  required SubRelType subRelType = 19;
  required string relClass = 20;	// one among the SubRel names, e.g. Provision.RelName.isProvidedBy

  required string source = 2;
  required string target = 3;

  /* if true then is a "child" */
  required bool child = 4;

  optional DNGFEntity cachedTarget = 5;

  // Datamodel rels
  optional DatasourceOrganization datasourceOrganization = 6;
  optional PersonPublication personPublication = 7;
  optional PersonDataset personDataset = 8;

  optional ProjectOrganization projectOrganization = 9;
  optional ProjectPerson projectPerson = 18;
  optional PublicationOrganization publicationOrganization = 10;

  optional PublicationProject publicationProject = 11;
  optional DatasetProject datasetProject = 12;

  optional PersonPerson personPerson = 15;
  optional PublicationPublication publicationPublication = 16;
  optional DatasetDataset datasetDataset = 22;
  optional PublicationDataset publicationDataset = 24;

  optional OrganizationOrganization organizationOrganization = 17;
  repeated KeyValue collectedfrom = 25;

}
